@@ -7,20 +7,22 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
 import { connect } from 'react-redux'
 import loadable from '@loadable/component'
 
-let RemoveResourceModal, ResourceModal, PolicyActionModal
+let RemoveResourceModal, PolicyActionModal, AnsibleAutomationModal
 
 const Modal = ({ type, open, ...rest }) => {
   switch (type) {
+  case 'resource-automation':
+    return open && getAnsibleAutomationModal({ type, open, ...rest })
   case 'resource-remove':
     return open && getRemoveResourceModal({ type, open, ...rest })
-  case 'resource-edit':
-    return open && getResourceModal({ type, open, ...rest })
   case 'resource-disable':
   case 'resource-enable':
   case 'resource-enforce':
@@ -31,6 +33,13 @@ const Modal = ({ type, open, ...rest }) => {
   }
 }
 
+const getAnsibleAutomationModal = props => {
+  AnsibleAutomationModal = AnsibleAutomationModal === undefined
+    ? loadable(() => import(/* webpackChunkName: "ansible-job-modal" */ '../modals/AnsibleAutomationModal/AnsibleAutomationModal'))
+    : AnsibleAutomationModal
+  return getModal(AnsibleAutomationModal, props)
+}
+
 const getPolicyActionModal = props => {
   PolicyActionModal = PolicyActionModal === undefined
     ? loadable(() => import(/* webpackChunkName: "policy-action-modal" */ '../modals/PolicyActionModal'))
@@ -38,13 +47,6 @@ const getPolicyActionModal = props => {
   return getModal(PolicyActionModal, props)
 }
 
-const getResourceModal = props => {
-  ResourceModal = ResourceModal === undefined
-    ? loadable(() => import(/* webpackChunkName: "edit-resource-modal" */ '../modals/ResourceModal'))
-    : ResourceModal
-  return getModal(ResourceModal, props)
-}
-
 const getRemoveResourceModal = props => {
   RemoveResourceModal = RemoveResourceModal === undefined
     ? loadable(() => import(/* webpackChunkName: "remove-resource-modal" */ '../modals/RemoveResourceModal'))
