@@ -7,6 +7,8 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 
 import React from 'react'
 import PropTypes from 'prop-types'
@@ -18,7 +20,7 @@ import {
 
 class StatusField extends React.PureComponent {
   static propTypes = {
-    status: PropTypes.oneOf(['ok', 'warning', 'failed', 'critical', 'offline', 'unknown', 'invalid', 'compliant', 'noncompliant']),
+    status: PropTypes.oneOf(['ok', 'warning', 'failed', 'critical', 'offline', 'unknown', 'nostatus', 'invalid', 'compliant', 'noncompliant']),
     text: PropTypes.string
   }
 
@@ -40,17 +42,18 @@ class StatusField extends React.PureComponent {
     case 'offline':
     case 'invalid':
     case 'unknown':
+    case 'nostatus':
     default :
       IconName = YellowExclamationTriangleIcon
       break
     }
     return (
-      <div className='table-status-row'>
-        <div className={`table-status-icon table-status-icon__${className}`}>
+      <span className='table-status-row'>
+        <span className={`table-status-icon table-status-icon__${className}`}>
           {<IconName /> }
-        </div>
-        <p>{this.props.text}</p>
-      </div>
+        </span>
+        <span className='table-status-label'>{this.props.text}</span>
+      </span>
     )
   }
 }
