@@ -1,14 +1,14 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import {
   breakWord,
   cellWidth,
-  sortable,
   wrappable,
 } from '@patternfly/react-table'
 import {
-  buildTimestamp,
   buildCompliantCellFromMessage,
   buildClusterLink,
   buildStatusHistoryLink,
@@ -19,30 +19,47 @@ export default {
   tableKeys: [
     {
       msgKey: 'table.header.cluster',
-      transforms: [sortable, wrappable],
+      label: 'cluster',
+      searchable: true,
+      sortable: true,
+      sortLabel: 'cluster.rawData',
+      resourceKey: 'cluster',
+      transforms: [wrappable],
       transformFunction: buildClusterLink
     },
     {
       msgKey: 'table.header.status',
+      label: 'status',
+      searchable: true,
+      sortable: true,
+      sortLabel: 'status.rawData',
       resourceKey: 'status',
-      transforms: [cellWidth(15), sortable],
+      transforms: [cellWidth(15)],
       transformFunction: buildCompliantCellFromMessage
     },
     {
       msgKey: 'table.header.message',
+      label: 'message',
+      searchable: true,
+      sortable: true,
+      sortLabel: 'message.rawData',
       resourceKey: 'message',
-      transforms: [cellWidth(70), sortable, wrappable],
+      transforms: [cellWidth(70), wrappable],
       cellTransforms: [breakWord],
       transformFunction: buildTemplateDetailLink
     },
     {
       msgKey: 'table.header.timestamp',
+      label: 'timestamp',
+      sortable: true,
+      sortLabel: 'timestamp.rawData',
       resourceKey: 'timestamp',
-      transforms: [sortable, wrappable],
-      transformFunction: buildTimestamp,
+      transforms: [wrappable],
+      type: 'timestamp'
     },
     {
       msgKey: 'table.header.history',
+      label: 'history',
       transforms: [wrappable],
       transformFunction: buildStatusHistoryLink
     },
