@@ -4,6 +4,7 @@ import typescript from 'typescript';
 const globals = {
   __proto__: null,
   tslib: "tslib",
+  assert: "assert",
 };
 
 function external(id) {
@@ -11,10 +12,10 @@ function external(id) {
 }
 
 export default [{
-  input: "src/context.ts",
+  input: "src/equality.ts",
   external,
   output: {
-    file: "lib/context.esm.js",
+    file: "lib/equality.esm.js",
     format: "esm",
     sourcemap: true,
     globals,
@@ -26,15 +27,32 @@ export default [{
     }),
   ],
 }, {
-  input: "lib/context.esm.js",
+  input: "lib/equality.esm.js",
   external,
   output: {
-    // Intentionally overwrite the context.js file written by tsc:
-    file: "lib/context.js",
+    // Intentionally overwrite the equality.js file written by tsc:
+    file: "lib/equality.js",
     format: "cjs",
     exports: "named",
     sourcemap: true,
-    name: "context",
+    name: "equality",
     globals,
   },
+}, {
+  input: "src/tests.ts",
+  external,
+  output: {
+    file: "lib/tests.cjs.js",
+    format: "cjs",
+    exports: "named",
+    sourcemap: true,
+    name: "equality-tests",
+    globals,
+  },
+  plugins: [
+    typescriptPlugin({
+      typescript,
+      tsconfig: "./tsconfig.test.json",
+    }),
+  ],
 }];
