@@ -4,13 +4,19 @@ export * from './Body';
 export * from './BodyCell';
 export * from './BodyWrapper';
 export * from './CollapseColumn';
+export * from './DraggableCell';
 export * from './EditableSelectInputCell';
 export * from './EditableTextCell';
 export * from './ExpandableRowContent';
 export * from './Header';
 export * from './HeaderCell';
+export * from './HeaderCellInfoWrapper';
 export * from './RowWrapper';
 export * from './SelectColumn';
 export * from './SortColumn';
 export * from './TableText';
 export * from './utils';
+export * from './TableTypes';
+export * from './TableContext';
+export * from './FavoritesCell';
+export * from './TreeRowWrapper';
